@@ -1,11 +1,13 @@
 from .fields import DjangoConnectionField, DjangoListField
 from .types import DjangoObjectType
+from .utils import bypass_get_queryset
 
-__version__ = "3.1.3"
+__version__ = "3.1.5"
 
 __all__ = [
     "__version__",
     "DjangoObjectType",
     "DjangoListField",
     "DjangoConnectionField",
+    "bypass_get_queryset",
 ]
