@@ -6,6 +6,7 @@
   React,
   ReactDOM,
   graphqlWs,
+  GraphiQLPluginExplorer,
   fetch,
   history,
   location,
@@ -60,40 +61,27 @@
 
   function trueLambda() { return true; };
 
-  var fetcher = GraphiQL.createFetcher({
+  var headers = {};
+  var cookies = ("; " + document.cookie).split("; csrftoken=");
+  if (cookies.length == 2) {
+    csrftoken = cookies.pop().split(";").shift();
+  } else {
+    csrftoken = document.querySelector("[name=csrfmiddlewaretoken]").value;
+  }
+  if (csrftoken) {
+    headers['X-CSRFToken'] = csrftoken
+  }
+
+  var graphQLFetcher = GraphiQL.createFetcher({
     url: fetchURL,
     wsClient: graphqlWs.createClient({
       url: subscribeURL,
       shouldRetry: trueLambda,
       lazy: true,
-    })
+    }),
+    headers: headers
   })
 
-  function graphQLFetcher(graphQLParams, opts) {
-    if (typeof opts === 'undefined') {
-      opts = {};
-    }
-    var headers = opts.headers || {};
-    headers['Accept'] = headers['Accept'] || 'application/json';
-    headers['Content-Type'] = headers['Content-Type'] || 'application/json';
-
-    // Parse the cookie value for a CSRF token
-    var csrftoken;
-    var cookies = ("; " + document.cookie).split("; csrftoken=");
-    if (cookies.length == 2) {
-      csrftoken = cookies.pop().split(";").shift();
-    } else {
-      csrftoken = document.querySelector("[name=csrfmiddlewaretoken]").value;
-    }
-    if (csrftoken) {
-      headers['X-CSRFToken'] = csrftoken
-    }
-
-    opts.headers = headers
-
-    return fetcher(graphQLParams, opts)
-  }
-
   // When the query and variables string is edited, update the URL bar so
   // that it can be easily shared.
   function onEditQuery(newQuery) {
@@ -111,24 +99,44 @@
   function updateURL() {
     history.replaceState(null, null, locationQuery(parameters));
   }
-  var options = {
-    fetcher: graphQLFetcher,
-    onEditQuery: onEditQuery,
-    onEditVariables: onEditVariables,
-    onEditOperationName: onEditOperationName,
-    isHeadersEditorEnabled: GRAPHENE_SETTINGS.graphiqlHeaderEditorEnabled,
-    shouldPersistHeaders: GRAPHENE_SETTINGS.graphiqlShouldPersistHeaders,
-    query: parameters.query,
-  };
-  if (parameters.variables) {
-    options.variables = parameters.variables;
-  }
-  if (parameters.operation_name) {
-    options.operationName = parameters.operation_name;
+
+  function GraphiQLWithExplorer() {
+    var [query, setQuery] = React.useState(parameters.query);
+
+    function handleQuery(query) {
+      setQuery(query);
+      onEditQuery(query);
+    }
+
+    var explorerPlugin = GraphiQLPluginExplorer.useExplorerPlugin({
+      query: query,
+      onEdit: handleQuery,
+    });
+
+    var options = {
+      fetcher: graphQLFetcher,
+      plugins: [explorerPlugin],
+      defaultEditorToolsVisibility: true,
+      onEditQuery: handleQuery,
+      onEditVariables: onEditVariables,
+      onEditOperationName: onEditOperationName,
+      isHeadersEditorEnabled: GRAPHENE_SETTINGS.graphiqlHeaderEditorEnabled,
+      shouldPersistHeaders: GRAPHENE_SETTINGS.graphiqlShouldPersistHeaders,
+      query: query,
+    };
+    if (parameters.variables) {
+      options.variables = parameters.variables;
+    }
+    if (parameters.operation_name) {
+      options.operationName = parameters.operation_name;
+    }
+
+    return React.createElement(GraphiQL, options);
   }
+
   // Render <GraphiQL /> into the body.
   ReactDOM.render(
-    React.createElement(GraphiQL, options),
+    React.createElement(GraphiQLWithExplorer),
     document.getElementById("editor"),
   );
 })(
@@ -139,6 +147,7 @@
   window.React,
   window.ReactDOM,
   window.graphqlWs,
+  window.GraphiQLPluginExplorer,
   window.fetch,
   window.history,
   window.location,
