@@ -37,18 +37,52 @@ def camelize(data):
     return data
 
 
-def get_reverse_fields(model, local_field_names):
-    for name, attr in model.__dict__.items():
-        # Don't duplicate any local fields
-        if name in local_field_names:
-            continue
+def _get_model_ancestry(model):
+    model_ancestry = [model]
 
-        # "rel" for FK and M2M relations and "related" for O2O Relations
-        related = getattr(attr, "rel", None) or getattr(attr, "related", None)
-        if isinstance(related, models.ManyToOneRel):
-            yield (name, related)
-        elif isinstance(related, models.ManyToManyRel) and not related.symmetrical:
-            yield (name, related)
+    for base in model.__bases__:
+        if is_valid_django_model(base) and getattr(base, "_meta", False):
+            model_ancestry.append(base)
+    return model_ancestry
+
+
+def get_reverse_fields(model, local_field_names):
+    """
+    Searches through the model's ancestry and gets reverse relationships the models
+    Yields a tuple of (field.name, field)
+    """
+    model_ancestry = _get_model_ancestry(model)
+
+    for _model in model_ancestry:
+        for name, attr in _model.__dict__.items():
+            # Don't duplicate any local fields
+            if name in local_field_names:
+                continue
+
+            # "rel" for FK and M2M relations and "related" for O2O Relations
+            related = getattr(attr, "rel", None) or getattr(attr, "related", None)
+            if isinstance(related, models.ManyToOneRel):
+                yield (name, related)
+            elif isinstance(related, models.ManyToManyRel) and not related.symmetrical:
+                yield (name, related)
+
+
+def get_local_fields(model):
+    """
+    Searches through the model's ancestry and gets the fields on the models
+    Returns a dict of {field.name: field}
+    """
+    model_ancestry = _get_model_ancestry(model)
+
+    local_fields_dict = {}
+    for _model in model_ancestry:
+        for field in sorted(
+            list(_model._meta.fields) + list(_model._meta.local_many_to_many)
+        ):
+            if field.name not in local_fields_dict:
+                local_fields_dict[field.name] = field
+
+    return list(local_fields_dict.items())
 
 
 def maybe_queryset(value):
@@ -58,17 +92,14 @@ def maybe_queryset(value):
 
 
 def get_model_fields(model):
-    local_fields = [
-        (field.name, field)
-        for field in sorted(
-            list(model._meta.fields) + list(model._meta.local_many_to_many)
-        )
-    ]
-
-    # Make sure we don't duplicate local fields with "reverse" version
-    local_field_names = [field[0] for field in local_fields]
+    """
+    Gets all the fields and relationships on the Django model and its ancestry.
+    Prioritizes local fields and relationships over the reverse relationships of the same name
+    Returns a tuple of (field.name, field)
+    """
+    local_fields = get_local_fields(model)
+    local_field_names = {field[0] for field in local_fields}
     reverse_fields = get_reverse_fields(model, local_field_names)
-
     all_fields = local_fields + list(reverse_fields)
 
     return all_fields
@@ -105,3 +136,12 @@ def set_rollback():
     atomic_requests = connection.settings_dict.get("ATOMIC_REQUESTS", False)
     if atomic_requests and connection.in_atomic_block:
         transaction.set_rollback(True)
+
+
+def bypass_get_queryset(resolver):
+    """
+    Adds a bypass_get_queryset attribute to the resolver, which is used to
+    bypass any custom get_queryset method of the DjangoObjectType.
+    """
+    resolver._bypass_get_queryset = True
+    return resolver
